@@ -376,8 +376,9 @@ MainObject::MainObject(QObject *parent)
 					(const char *)RDCheckDateTime(q1->value(17).
 					toTime(),"hh:mm:ss"));//Invalid possible?
       }
-      RDCut::create(q1->value(0).toString());
-      sql=QString("update CUTS set ")+
+      sql=QString("insert into CUTS set ")+
+	"CUT_NAME=\""+RDEscapeString(q1->value(0).toString())+"\","+
+	QString().sprintf("CART_NUMBER=%u,",q->value(0).toUInt())+
 	"EVERGREEN=\""+RDEscapeString(q1->value(1).toString())+"\","+
 	"DESCRIPTION=\""+RDEscapeString(q1->value(2).toString())+"\","+
 	"OUTCUE=\""+RDEscapeString(q1->value(3).toString())+"\","+
@@ -413,8 +414,7 @@ MainObject::MainObject(QObject *parent)
 	QString().sprintf("HOOK_START_POINT=%d,",q1->value(33).toInt())+
 	QString().sprintf("HOOK_END_POINT=%d,",q1->value(34).toInt())+
 	QString().sprintf("TALK_START_POINT=%d,",q1->value(35).toInt())+
-	QString().sprintf("TALK_END_POINT=%d where ",q1->value(36).toInt())+
-	"CUT_NAME=\""+RDEscapeString(q1->value(0).toString())+"\"";
+	QString().sprintf("TALK_END_POINT=%d",q1->value(36).toInt());
       q2=new QSqlQuery(sql,filter_db);
       delete q2;
       ok=RDCopy(QString().sprintf("%s%s.%s",(const char *)ext_audiodir,
