@@ -2,7 +2,7 @@
 //
 // Export a Rivendell Classical Music Playout report
 //
-//   (C) Copyright 2014,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2014,2016-2017 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -29,7 +29,8 @@
 #include <rddatedecode.h>
 #include <rdreport.h>
 
-bool RDReport::ExportMusicClassical(const QDate &startdate,const QDate &enddate,
+bool RDReport::ExportMusicClassical(const QString &filename,
+				    const QDate &startdate,const QDate &enddate,
 				    const QString &mixtable)
 {
   QString sql;
@@ -40,12 +41,6 @@ bool RDReport::ExportMusicClassical(const QDate &startdate,const QDate &enddate,
   QString cart_fmt;
   QString cart_num;
 
-#ifdef WIN32
-  QString filename=RDDateDecode(exportPath(RDReport::Windows),startdate);
-#else
-  QString filename=RDDateDecode(exportPath(RDReport::Linux),startdate);
-#endif
-
   QFile file(filename);
   if((f=fopen((const char *)filename,"w"))==NULL) {
     report_error_code=RDReport::ErrorCantOpen;
