@@ -2,9 +2,7 @@
 //
 // Export an Audio File using the RdXport Web Service
 //
-//   (C) Copyright 2010 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdaudioexport.h,v 1.4.4.1 2013/11/13 23:36:30 cvs Exp $
+//   (C) Copyright 2010-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -38,11 +36,14 @@ class RDAudioExport : public QObject
 		  ErrorNoDestination=3,ErrorInternal=5,ErrorUrlInvalid=7,
 		  ErrorService=8,ErrorInvalidUser=9,ErrorAborted=10,
 		  ErrorConverter=11};
-  RDAudioExport(RDStation *station,RDConfig *config,QObject *parent=0,
-		const char *name=0);
+  RDAudioExport(RDStation *station,RDConfig *config,QObject *parent=0);
+  unsigned cartNumber() const;
   void setCartNumber(unsigned cartnum);
+  unsigned cutNumber() const;
   void setCutNumber(unsigned cutnum);
+  QString destinationFile() const;
   void setDestinationFile(const QString &filename);
+  RDSettings *destinationSettings() const;
   void setDestinationSettings(RDSettings *settings);
   void setRange(int start_pt,int end_pt);
   void setEnableMetadata(bool state);
