@@ -1,12 +1,9 @@
-// rconf.c
-// A small library for handling common configuration file tasks
+// rdconf.cpp
+//
+//  Small library for handling common configuration file tasks
 // 
-// Adopted from conflib
-//
 //   (C) Copyright 1996-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//    $Id: rdconf.cpp,v 1.15.4.7.2.1 2014/06/24 18:27:04 cvs Exp $
-//
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU Library General Public License 
 //   version 2 as published by the Free Software Foundation.
@@ -966,29 +963,6 @@ QString RDHomeDir()
 }
 
 
-QString RDTempDir()
-{
-  QString conf_temp_directory = RDConfiguration()->tempDirectory();
-  if (!conf_temp_directory.isEmpty()) {
-    return conf_temp_directory;
-  }
-#ifdef WIN32
-  if(getenv("TEMP")!=NULL) {
-    return QString(getenv("TEMP"));
-  }
-  if(getenv("TMP")!=NULL) {
-    return QString(getenv("TMP"));
-  }
-  return QString("C:\\");
-#else
-  if(getenv("TMPDIR")!=NULL) {
-    return QString(getenv("TMPDIR"));
-  }
-  return QString("/tmp");
-#endif  // WIN32
-}
-
-
 QString RDTempFile()
 {
 #ifndef WIN32
