@@ -2,7 +2,7 @@
 //
 // A container class for a Rivendell Base Configuration
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,12 +20,16 @@
 
 #ifndef WIN32
 #include <sys/types.h>
-#include <sys/stat.h>
 #include <pwd.h>
 #include <grp.h>
+#include <unistd.h>
+#include <arpa/inet.h>
+#include <net/if.h>
+#include <sys/ioctl.h>
 #endif  // WIN32
 
 #include <qmessagebox.h>
+#include <qregexp.h>
 #include <qsettings.h>
 #include <qstringlist.h>
 
@@ -176,6 +180,30 @@ int RDConfig::mysqlHeartbeatInterval() const
 }
 
 
+QString RDConfig::mysqlEngine() const
+{
+  return conf_mysql_engine;
+}
+
+
+QString RDConfig::mysqlCharset() const
+{
+  return conf_mysql_charset;
+}
+
+
+QString RDConfig::mysqlCollation() const
+{
+  return conf_mysql_collation;
+}
+
+
+QString RDConfig::createTablePostfix() const
+{
+  return conf_create_table_postfix;
+}
+
+
 RDConfig::LogFacility RDConfig::logFacility() const
 {
   return conf_log_facility;
@@ -261,6 +289,25 @@ QString RDConfig::provisioningHostTemplate() const
 }
 
 
+QHostAddress RDConfig::provisioningHostIpAddress() const
+{
+  return conf_provisioning_host_ip_address;
+}
+
+
+QString RDConfig::provisioningHostShortName(const QString &hostname) const
+{
+  QRegExp exp(conf_provisioning_host_short_name_regex);
+
+  exp.search(hostname);
+  QStringList texts=exp.capturedTexts();
+  if(texts.size()<conf_provisioning_host_short_name_group) {
+    return QString();
+  }
+  return texts[conf_provisioning_host_short_name_group];
+}
+
+
 bool RDConfig::provisioningCreateService() const
 {
   return conf_provisioning_create_service;
@@ -273,6 +320,19 @@ QString RDConfig::provisioningServiceTemplate() const
 }
 
 
+QString RDConfig::provisioningServiceName(const QString &hostname) const
+{
+  QRegExp exp(conf_provisioning_service_name_regex);
+
+  exp.search(hostname);
+  QStringList texts=exp.capturedTexts();
+  if(texts.size()<conf_provisioning_service_name_group) {
+    return QString();
+  }
+  return texts[conf_provisioning_service_name_group];
+}
+
+
 int RDConfig::alsaPeriodQuantity() const
 {
   return conf_alsa_period_quantity;
@@ -406,6 +466,21 @@ int RDConfig::realtimePriority()
   return conf_realtime_priority;
 }
 
+
+int RDConfig::transcodingDelay() const
+{
+  return conf_transcoding_delay;
+}
+
+
+#ifndef WIN32
+mode_t RDConfig::tuningExportedFileMode() const
+{
+  return conf_tuning_exported_file_mode;
+}
+#endif  // WIN32
+
+
 // Don't use this method in application code, use RDTempDirectory()
 QString RDConfig::tempDirectory()
 {
@@ -450,6 +525,7 @@ void RDConfig::load()
   char sname[256];
   QString client;
   QString facility;
+  QString iface;
 #ifndef WIN32
   struct passwd *user;
   struct group *groups;
@@ -489,10 +565,19 @@ void RDConfig::load()
     profile->boolValue("Provisioning","CreateHost");
   conf_provisioning_host_template=
     profile->stringValue("Provisioning","NewHostTemplate");
+  iface=profile->stringValue("Provisioning","NewHostIpAddress","lo");
+  conf_provisioning_host_short_name_regex=
+    profile->stringValue("Provisioning","NewHostShortNameRegex","[^*]*");
+  conf_provisioning_host_short_name_group=
+    profile->intValue("Provisioning","NewHostShortNameGroup");
   conf_provisioning_create_service=
     profile->boolValue("Provisioning","CreateService");
   conf_provisioning_service_template=
     profile->stringValue("Provisioning","NewServiceTemplate");
+  conf_provisioning_service_name_regex=
+    profile->stringValue("Provisioning","NewServiceNameRegex","[^*]*");
+  conf_provisioning_service_name_group=
+    profile->intValue("Provisioning","NewServiceNameGroup");
 
   conf_audio_root=
     profile->stringValue("Cae","AudioRoot",RD_AUDIO_ROOT);
@@ -510,6 +595,15 @@ void RDConfig::load()
   conf_mysql_heartbeat_interval=
     profile->intValue("mySQL","HeartbeatInterval",
 		      DEFAULT_MYSQL_HEARTBEAT_INTERVAL);
+  conf_mysql_engine=
+    profile->stringValue("mySQL","Engine",DEFAULT_MYSQL_ENGINE);
+  conf_mysql_charset=
+    profile->stringValue("mySQL","Charset",DEFAULT_MYSQL_CHARSET);
+  conf_mysql_collation=
+    profile->stringValue("mySQL","Collation",DEFAULT_MYSQL_COLLATION);
+  conf_create_table_postfix=QString(" engine ")+conf_mysql_engine+" "+
+    "character set "+conf_mysql_charset+" "+
+    "collate "+conf_mysql_collation;
 
   facility=profile->stringValue("Logs","Facility",DEFAULT_LOG_FACILITY).lower();
   if(facility=="syslog") {
@@ -553,6 +647,13 @@ void RDConfig::load()
   conf_enable_mixer_logging=profile->boolValue("Caed","EnableMixerLogging");
   conf_use_realtime=profile->boolValue("Tuning","UseRealtime",false);
   conf_realtime_priority=profile->intValue("Tuning","RealtimePriority",9);
+  conf_transcoding_delay=profile->intValue("Tuning","TranscodingDelay");
+#ifndef WIN32
+  conf_tuning_exported_file_mode=profile->
+    stringValue("Tuning","ExportedFileMode",
+		QString().sprintf("%o",RD_TUNING_DEFAULT_EXPORTED_FILE_MODE)).
+    toInt(NULL,8);
+#endif  // WIN32
   conf_temp_directory=profile->stringValue("Tuning","TempDirectory","");
   conf_sas_station=profile->stringValue("SASFilter","Station","");
   conf_sas_matrix=profile->intValue("SASFilter","Matrix",0);
@@ -566,6 +667,33 @@ void RDConfig::load()
     conf_destinations.push_back(dest);
   }
   delete profile;
+
+  //
+  // Resolve Interface Address
+  //
+  int sock=-1;
+
+#ifndef WIN32
+  if((sock=socket(PF_INET,SOCK_DGRAM,IPPROTO_IP))<0) {
+    return;
+  }
+  struct ifreq ifr;
+  int index=0;
+
+  memset(&ifr,0,sizeof(ifr));
+  index=1;
+  ifr.ifr_ifindex=index;
+  while(ioctl(sock,SIOCGIFNAME,&ifr)==0) {
+    if(ifr.ifr_name==iface) {
+      if(ioctl(sock,SIOCGIFADDR,&ifr)==0) {
+	struct sockaddr_in sa=*(sockaddr_in *)(&ifr.ifr_addr);
+	conf_provisioning_host_ip_address.setAddress(ntohl(sa.sin_addr.s_addr));
+      }
+    }
+    ifr.ifr_ifindex=++index;
+  }
+  close(sock);
+#endif  // WIN32
 }
 
 
@@ -588,6 +716,10 @@ void RDConfig::clear()
   conf_mysql_password="";
   conf_mysql_driver="";
   conf_mysql_heartbeat_interval=DEFAULT_MYSQL_HEARTBEAT_INTERVAL;
+  conf_mysql_engine=DEFAULT_MYSQL_ENGINE;
+  conf_mysql_charset=DEFAULT_MYSQL_CHARSET;
+  conf_mysql_collation=DEFAULT_MYSQL_COLLATION;
+  conf_create_table_postfix="";
   conf_log_facility=RDConfig::LogSyslog;
   conf_log_directory="";
   conf_log_core_dump_directory=DEFAULT_LOG_CORE_DUMP_DIRECTORY;
@@ -595,6 +727,9 @@ void RDConfig::clear()
   conf_log_xload_debug_data=false;
   conf_provisioning_create_host=false;
   conf_provisioning_host_template="";
+  conf_provisioning_host_ip_address.setAddress("127.0.0.2");
+  conf_provisioning_host_short_name_regex="[^%]*";
+  conf_provisioning_host_short_name_group=0;
   conf_provisioning_create_service=false;
   conf_provisioning_service_template="";
   conf_alsa_period_quantity=RD_ALSA_DEFAULT_PERIOD_QUANTITY;
@@ -629,6 +764,10 @@ void RDConfig::clear()
   conf_enable_mixer_logging=false;
   conf_use_realtime=false;
   conf_realtime_priority=9;
+#ifndef WIN32
+  conf_tuning_exported_file_mode=RD_TUNING_DEFAULT_EXPORTED_FILE_MODE;
+#endif  // WIN32
+  conf_transcoding_delay=0;
   conf_temp_directory="";
   conf_sas_station="";
   conf_sas_matrix=-1;
