@@ -2,7 +2,7 @@
 //
 // A container class for a Rivendell Base Configuration
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -26,8 +26,11 @@
 #include <unistd.h>
 #endif  // WIN32
 
+#include <sys/stat.h>
+
 #include <vector>
 
+#include <qhostaddress.h>
 #include <qstring.h>
 
 #include <rd.h>
@@ -59,6 +62,10 @@ class RDConfig
   QString mysqlPassword() const;
   QString mysqlDriver() const;
   int mysqlHeartbeatInterval() const;
+  QString mysqlEngine() const;
+  QString mysqlCharset() const;
+  QString mysqlCollation() const;
+  QString createTablePostfix() const;
   RDConfig::LogFacility logFacility() const;
   QString logDirectory() const;
   QString logCoreDumpDirectory() const;
@@ -67,8 +74,11 @@ class RDConfig
   void log(const QString &module,LogPriority prio,const QString &msg);
   bool provisioningCreateHost() const;
   QString provisioningHostTemplate() const;
+  QHostAddress provisioningHostIpAddress() const;
+  QString provisioningHostShortName(const QString &hostname) const;
   bool provisioningCreateService() const;
   QString provisioningServiceTemplate() const;
+  QString provisioningServiceName(const QString &hostname) const;
   int alsaPeriodQuantity() const;
   int alsaPeriodSize() const;
   int alsaChannelsPerPcm() const;
@@ -102,6 +112,10 @@ class RDConfig
 #endif
   bool useRealtime();
   int realtimePriority();
+  int transcodingDelay() const;
+#ifndef WIN32
+  mode_t tuningExportedFileMode() const;
+#endif  // WIN32
   QString tempDirectory();
   QString sasStation() const;
   int sasMatrix() const;
@@ -120,6 +134,10 @@ class RDConfig
   QString conf_mysql_dbname;
   QString conf_mysql_password;
   QString conf_mysql_driver;
+  QString conf_mysql_engine;
+  QString conf_mysql_charset;
+  QString conf_mysql_collation;
+  QString conf_create_table_postfix;
   int conf_mysql_heartbeat_interval;
   RDConfig::LogFacility conf_log_facility;
   QString conf_log_directory;
@@ -127,8 +145,13 @@ class RDConfig
   QString conf_log_pattern;
   bool conf_provisioning_create_host;
   QString conf_provisioning_host_template;
+  QHostAddress conf_provisioning_host_ip_address;
+  QString conf_provisioning_host_short_name_regex;
+  unsigned conf_provisioning_host_short_name_group;
   bool conf_provisioning_create_service;
   QString conf_provisioning_service_template;
+  QString conf_provisioning_service_name_regex;
+  unsigned conf_provisioning_service_name_group;
   bool conf_log_xload_debug_data;
   int conf_alsa_period_quantity;
   int conf_alsa_period_size;
@@ -156,10 +179,12 @@ class RDConfig
 #ifndef WIN32
   uid_t conf_uid;
   gid_t conf_gid;
+  mode_t conf_tuning_exported_file_mode;
 #endif
   QString conf_cae_logfile;
   bool conf_enable_mixer_logging;
   bool conf_use_realtime;
+  int conf_transcoding_delay;
   int conf_realtime_priority;
   QString conf_temp_directory;
   QString conf_sas_station;
