@@ -59,6 +59,8 @@ class RDCut
   void setIsrc(const QString &isrc) const;
   QString isci() const;
   void setIsci(const QString &isci) const;
+  QString sha1Hash() const;
+  void setSha1Hash(const QString &str);
   unsigned length() const;
   void setLength(int length) const;
   QDateTime originDatetime(bool *valid) const;
@@ -75,6 +77,10 @@ class RDCut
   void setWeekPart(int dayofweek,bool state) const;
   QString originName() const;
   void setOriginName(const QString &name) const;
+  QString originLoginName() const;
+  void setOriginLoginName(const QString &name) const;
+  QString sourceHostname() const;
+  void setSourceHostname(const QString &name) const;
   unsigned weight() const;
   void setWeight(int value) const;
   int playOrder() const;
@@ -128,7 +134,8 @@ class RDCut
 	      RDConfig *config) const;
   void getMetadata(RDWaveData *data) const;
   void setMetadata(RDWaveData *data) const;
-  bool checkInRecording(const QString &stationname,RDSettings *settings,
+  bool checkInRecording(const QString &station_name,const QString &user_name,
+			QString src_hostname,RDSettings *settings,
 			unsigned msecs) const;
   void autoTrim(RDCut::AudioEnd end,int level);
   void autoSegue(int level,int length,RDStation *station,RDUser *user,
@@ -140,6 +147,8 @@ class RDCut
   static QString cutName(unsigned cartnum,unsigned cutnum);
   static unsigned cartNumber(const QString &cutname);
   static unsigned cutNumber(const QString &cutname);
+  static bool create(unsigned cartnum,int cutnum);
+  static bool create(const QString &cutname);
   static bool exists(unsigned cartnum,unsigned cutnum);
   static bool exists(const QString &cutname);
   static QString pathName(unsigned cartnum,unsigned cutnum);
@@ -154,6 +163,8 @@ class RDCut
   void SetRow(const QString &param,const QDate &value) const;
   void SetRow(const QString &param,const QTime &value) const;
   void SetRow(const QString &param) const;
+  static void GetDefaultDateTimes(QString *start_dt,QString *end_dt,
+				  const QString &cutname);
   QSignal *cut_signal;
   QSqlDatabase *cut_db;
   QString cut_name;
