@@ -2,9 +2,7 @@
 //
 // Get the full Cut Path for a given Cut Name.
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdcut_path.cpp,v 1.8 2010/07/29 19:32:33 cvs Exp $
+//   (C) Copyright 2002-2003,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,11 +18,12 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include <qobject.h>
+
 #include <rdcut.h>
 #include <rdcart.h>
 #include <rdcut_path.h>
 
-
 QString RDCutPath(QString cutname)
 {
   QString path;
@@ -32,7 +31,7 @@ QString RDCutPath(QString cutname)
   RDCut *cut=new RDCut(cutname); 
   if(!cut->exists()) {
     delete cut;
-    return QString(QT_TR_NOOP("UNKNOWN CUT"));
+    return QString(QObject::tr("UNKNOWN CUT"));
   }
   RDCart *cart=new RDCart(cut->cartNumber());
 
