@@ -2,9 +2,7 @@
 //
 // Abstract a Rivendell Service
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdgroup.h,v 1.13.6.1 2008/11/30 00:32:57 fredg Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -43,10 +41,15 @@ class RDGroup
   void setDefaultLowCart(unsigned cartnum) const;
   unsigned defaultHighCart() const;
   void setDefaultHighCart(unsigned cartnum) const;
+  int defaultCutLife() const;
+  void setDefaultCutLife(int days) const;
   int cutShelflife() const;
   void setCutShelflife(int days) const;
+  bool deleteEmptyCarts() const;
+  void setDeleteEmptyCarts(bool state) const;
   QString defaultTitle() const;
   void setDefaultTitle(const QString &str);
+  QString generateTitle(const QString &pathname);
   bool enforceCartRange() const;
   void setEnforceCartRange(bool state) const;
   bool exportReport(ExportType type) const;
@@ -57,9 +60,20 @@ class RDGroup
   void setColor(const QColor &color);
   unsigned nextFreeCart(unsigned startcart=0) const;
   int freeCartQuantity() const;
+#ifndef WIN32
+  bool reserveCarts(std::vector<unsigned> *cart_nums,
+		    const QString &station_name,RDCart::Type type,
+		    unsigned quan) const;
+#endif  // WIN32
   bool cartNumberValid(unsigned cartnum) const;
+  QString xml() const;
   
  private:
+  unsigned GetNextFreeCart(unsigned startcart) const;
+#ifndef WIN32
+  bool ReserveCart(const QString &station_name,RDCart::Type type,
+		   unsigned cart_num) const;
+#endif  // WIN32
   void SetRow(const QString &param,int value) const;
   void SetRow(const QString &param,unsigned value) const;
   void SetRow(const QString &param,const QString &value) const;
