@@ -2,9 +2,7 @@
 //
 // A widget to set an integer value.
 //
-//   (C) Copyright 2008 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdintegerdialog.h,v 1.3 2010/07/29 19:32:33 cvs Exp $
+//   (C) Copyright 2008,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -31,7 +29,7 @@ class RDIntegerDialog : public QDialog
  Q_OBJECT
  public:
   RDIntegerDialog(int *value,const QString &lbl,int low,int high,
-		  QWidget *parent=0,const char *name=0);
+		  QWidget *parent=0);
   ~RDIntegerDialog();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
