@@ -2,9 +2,7 @@
 //
 // Output a string on a Rivendell TTY
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdttyout.h,v 1.5 2008/08/04 19:05:34 fredg Exp $
+//   (C) Copyright 2002-2003,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,15 +18,15 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#ifndef RDTTYOUT_H
+#define RDTTYOUT_H
+
 #include <qstring.h>
 #include <qsqldatabase.h>
 
 #include <rdttydevice.h>
 
-#ifndef RDTTYOUT_H
-#define RDTTYOUT_H
-
 bool RDTtyOut(const QString &station,unsigned port_id,const QString &string);
 
 
-#endif 
+#endif  // RDTTYOUT_H
