@@ -2,9 +2,7 @@
 //
 // Edit a List of Autofill Carts
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: autofill_carts.h,v 1.6 2010/07/29 19:32:34 cvs Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -33,7 +31,7 @@ class AutofillCarts : public QDialog
 {
  Q_OBJECT
  public:
-  AutofillCarts(RDSvc *svc,QWidget *parent=0,const char *name=0);
+  AutofillCarts(RDSvc *svc,QWidget *parent=0);
   ~AutofillCarts();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
