@@ -2,9 +2,7 @@
 //
 // Edit an RDAirPlay Configuration
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: edit_rdairplay.cpp,v 1.53.6.9 2014/02/11 23:46:26 cvs Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -46,8 +44,8 @@
 #include <edit_channelgpios.h>
 
 EditRDAirPlay::EditRDAirPlay(RDStation *station,RDStation *cae_station,
-			     QWidget *parent,const char *name)
-  : QDialog(parent,name,true)
+			     QWidget *parent)
+  : QDialog(parent,"",true)
 {
   QString sql;
   RDSqlQuery *q;
@@ -83,7 +81,7 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,RDStation *cae_station,
   //
   // Dialog Name
   //
-  setCaption(tr("RDAirPlay config for ")+station->name());
+  setCaption(tr("Configure RDAirPlay"));
 
   //
   // Channel Assignments Section
@@ -218,11 +216,6 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,RDStation *cae_station,
   //
   // Audition/Cue Output
   //
-  /*
-  label=new QLabel(tr("Audition/Cue Output"),this);
-  label->setFont(small_font);
-  label->setGeometry(25,304,200,16);
-  */
   air_card_sel[3]=new RDCardSelector(this);
   air_card_sel[3]->setId(3);
   air_card_sel[3]->setGeometry(20,322,120,117);
@@ -506,8 +499,8 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,RDStation *cae_station,
   air_station_box->setGeometry(895,204,50,20);
   air_station_box->setRange(0,MAX_PANELS);
   air_station_box->setSpecialValueText(tr("None"));
-  air_station_label=new QLabel(air_station_box,tr("Host Panels:"),this);
-  air_station_label->setGeometry(790,204,100,20);
+  air_station_label=new QLabel(air_station_box,tr("System Panels:"),this);
+  air_station_label->setGeometry(750,204,140,20);
   air_station_label->setAlignment(AlignRight|AlignVCenter);
 
   //
@@ -518,7 +511,7 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,RDStation *cae_station,
   air_user_box->setRange(0,MAX_PANELS);
   air_user_box->setSpecialValueText(tr("None"));
   air_user_label=new QLabel(air_user_box,tr("User Panels:"),this);
-  air_user_label->setGeometry(790,226,100,20);
+  air_user_label->setGeometry(750,226,140,20);
   air_user_label->setAlignment(AlignRight|AlignVCenter);
 
   //
@@ -811,7 +804,7 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,RDStation *cae_station,
   //
   //  Ok Button
   //
-  button=new QPushButton(this,"ok_button");
+  button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
   button->setDefault(true);
   button->setFont(small_font);
@@ -821,7 +814,7 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,RDStation *cae_station,
   //
   //  Cancel Button
   //
-  button=new QPushButton(this,"cancel_button");
+  button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,80,50);
   button->setFont(small_font);
   button->setText(tr("&Cancel"));
@@ -1007,8 +1000,8 @@ void EditRDAirPlay::selectData()
 {
   QString logname=air_startlog_edit->text();
 
-  RDListLogs *ll=new RDListLogs(&logname,air_conf->station(),this,
-                                "log",admin_user);
+  RDListLogs *ll=new RDListLogs(&logname,RDLogFilter::NoFilter,admin_user,
+				admin_config,this);
   if(ll->exec()==0) {
     air_startlog_edit->setText(logname);
   }
@@ -1018,7 +1011,7 @@ void EditRDAirPlay::selectData()
 
 void EditRDAirPlay::nownextData()
 {
-  EditNowNext *edit=new EditNowNext(air_conf,this,"edit");
+  EditNowNext *edit=new EditNowNext(air_conf,this);
   edit->exec();
   delete edit;
 }
@@ -1026,9 +1019,8 @@ void EditRDAirPlay::nownextData()
 void EditRDAirPlay::editHotKeys()
 {
   QString module_name = QString("airplay");
-  EditHotkeys *edit_hotkeys=new EditHotkeys(air_conf->station(),
-		                (const char *)module_name,
-				this,"hotkeys");
+  EditHotkeys *edit_hotkeys=
+    new EditHotkeys(air_conf->station(),(const char *)module_name,this);
   edit_hotkeys->exec();
   delete edit_hotkeys;
 }
