@@ -833,8 +833,7 @@ void LogPlay::insert(int line,int cartnum,RDLogLine::TransType next_type,
   if(nextLine()<0) {
     play_next_line=line;
   }
-  logline->loadCart(cartnum,next_type,play_id,play_timescaling_available,
-		    rdairplay_conf->defaultTransType());
+  logline->loadCart(cartnum,next_type,play_id,play_timescaling_available,type);
   logline->
     setTimescalingActive(play_timescaling_available&&logline->enforceLength());
   UpdateStartTimes(line);
@@ -1361,6 +1360,14 @@ void LogPlay::resync()
 }
 
 
+bool LogPlay::isRefreshable() const
+{
+  return (play_log->exists())&&
+    (play_log->linkDatetime()==play_link_datetime)&&
+    (play_log->modifiedDatetime()>play_modified_datetime);
+}
+  
+
 void LogPlay::transTimerData()
 {
   int lines[TRANSPORT_QUANTITY];
