@@ -2,9 +2,7 @@
 //
 // Add a Rivendell RDCatch Event
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: add_recording.h,v 1.13 2007/12/31 18:49:09 fredg Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -39,7 +37,7 @@ class AddRecording : public QDialog
 {
   Q_OBJECT
  public:
-  AddRecording(int id,QString *filter,QWidget *parent=0,const char *name=0);
+  AddRecording(int id,QString *filter,QWidget *parent=0);
   ~AddRecording();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
