@@ -2,9 +2,7 @@
 //
 // An automated event executer.
 //
-//   (C) Copyright 2002 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdcatchd_socket.cpp,v 1.4 2007-09-14 14:06:52 fredg Exp $
+//   (C) Copyright 2002,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,7 +18,6 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-
 #include <qapplication.h>
 #include <qobject.h>
 #include <qserversocket.h>
@@ -32,9 +29,8 @@
 
 #include <rdcatchd_socket.h>
 
-RDCatchdSocket::RDCatchdSocket(Q_UINT16 port,int backlog,QObject *parent,
-		     const char *name) 
-  : QServerSocket(port,0,parent,name)
+RDCatchdSocket::RDCatchdSocket(Q_UINT16 port,int backlog,QObject *parent)
+  : QServerSocket(port,0,parent)
 {
 }
 
