@@ -279,11 +279,11 @@ Wollen Sie trotzdem speichern?</translation>
     </message>
     <message>
         <source>Log Exists</source>
-        <translation>Log existiert</translation>
+        <translation type="obsolete">Log existiert</translation>
     </message>
     <message>
         <source>Log Already Exists!</source>
-        <translation>Log existiert bereits!</translation>
+        <translation type="obsolete">Log existiert bereits!</translation>
     </message>
     <message>
         <source>RDLogEdit</source>
@@ -421,6 +421,22 @@ die für den gewählten Service ungültig sind!</translation>
         <source>Render</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>User</source>
+        <translation type="obsolete">Benutzer</translation>
+    </message>
+    <message>
+        <source>Log Locked</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log already being edited by</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditLogLine</name>
@@ -651,27 +667,27 @@ Gruppe des ausgewählten Service!</translation>
     <name>ListLogs</name>
     <message>
         <source>Select a Log</source>
-        <translation>Ein Log auswählen</translation>
+        <translation type="obsolete">Ein Log auswählen</translation>
     </message>
     <message>
         <source>NAME</source>
-        <translation>NAME</translation>
+        <translation type="obsolete">NAME</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>BESCHREIBUNG</translation>
+        <translation type="obsolete">BESCHREIBUNG</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation>SERVICE</translation>
+        <translation type="obsolete">SERVICE</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>Abbre&amp;chen</translation>
+        <translation type="obsolete">Abbre&amp;chen</translation>
     </message>
 </context>
 <context>
@@ -821,11 +837,11 @@ Report</translation>
     </message>
     <message>
         <source>Log Exists</source>
-        <translation>Log existiert</translation>
+        <translation type="obsolete">Log existiert</translation>
     </message>
     <message>
         <source>Log Already Exists!</source>
-        <translation>Log existiert bereits!</translation>
+        <translation type="obsolete">Log existiert bereits!</translation>
     </message>
     <message>
         <source>Delete Log</source>
@@ -838,7 +854,7 @@ Report</translation>
     <message>
         <source>voice tracks associated with this log.
 Continue?</source>
-        <translation>Voice Tracks die mit diesem Log verbunden sind.
+        <translation type="obsolete">Voice Tracks die mit diesem Log verbunden sind.
 Fortfahren?</translation>
     </message>
     <message>
@@ -855,11 +871,11 @@ Fortfahren?</translation>
     </message>
     <message>
         <source>RDLogEdit</source>
-        <translation>RDLogEdit</translation>
+        <translation type="obsolete">RDLogEdit</translation>
     </message>
     <message>
         <source>Unable to delete log, audio deletion error!</source>
-        <translation>Kann Logdatei nicht löschen, Audiolöschfehler!</translation>
+        <translation type="obsolete">Kann Logdatei nicht löschen, Audiolöschfehler!</translation>
     </message>
     <message>
         <source>RDLogEdit -- Database Skew</source>
@@ -879,23 +895,150 @@ See your system administrator for an update!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Service</source>
+        <source>Are you sure you want to delete the</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>ALL</source>
+        <source>log?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Filter</source>
+        <source>voice tracks associated with this log.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Clear</source>
+        <source>Continue?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Show Only Recent Logs</source>
+        <source>Are you sure you want to delete these</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>logs?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>voice tracks associated with these logs.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to delete log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>audio deletion error!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Windows</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is in use by</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>RenderDialog</name>
+    <message>
+        <source>Render Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rendering Log...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Render Progress</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart/Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Render To</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select</source>
+        <translation type="unfinished">Auswählen</translation>
+    </message>
+    <message>
+        <source>Audio Parameters</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>[now]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>As Specified</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Virtual Start Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Events</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Only Selected Events</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Include</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Stop Rendering</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Treat as PLAY</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>At STOP transition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Render</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished">Abbre&amp;chen</translation>
+    </message>
+    <message>
+        <source>Filename</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rendering Error</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1126,5 +1269,13 @@ therefore only existing transitions will be editable.</source>
         <source>LABEL</source>
         <translation type="unfinished">LABEL</translation>
     </message>
+    <message>
+        <source>Log Locked</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log already being edited by</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
