@@ -2,9 +2,7 @@
 //
 // Edit RDLogManager Service Associations
 //
-//   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: edit_perms.h,v 1.6 2010/07/29 19:32:37 cvs Exp $
+//   (C) Copyright 2002-2005,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -30,14 +28,12 @@
 
 #include <rdsvc.h>
 
-
 class EditPerms : public QDialog
 {
   Q_OBJECT
  public:
   enum ObjectType {ObjectEvent=1,ObjectClock=2};
-  EditPerms(QString object_name,ObjectType type,
-	    QWidget *parent=0,const char *name=0);
+  EditPerms(QString object_name,ObjectType type,QWidget *parent=0);
   ~EditPerms();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
@@ -46,6 +42,9 @@ class EditPerms : public QDialog
   void okData();
   void cancelData();
 
+ protected:
+  void closeEvent(QCloseEvent *e);
+
  private:
   RDListSelector *svc_object_sel;
   ObjectType sel_type;
