@@ -2,9 +2,7 @@
 //
 // A Rivendell switcher driver for the BroadcastTools ACS 8.2
 //
-//   (C) Copyright 2002-2008 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: btacs82.h,v 1.11 2010/08/03 23:39:25 cvs Exp $
+//   (C) Copyright 2002-2008,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -35,12 +33,11 @@
 #define BTACS82_POLL_INTERVAL 100
 #define BTACS82_GPIO_PINS 16
 
-
 class BtAcs82 : public Switcher
 {
  Q_OBJECT
  public:
-  BtAcs82(RDMatrix *matrix,QObject *parent=0,const char *name=0);
+  BtAcs82(RDMatrix *matrix,QObject *parent=0);
   ~BtAcs82();
   RDMatrix::Type type();
   unsigned gpiQuantity();
