@@ -2,9 +2,7 @@
 //
 // A Rivendell switcher driver for the BroadcastTools SRC-16
 //
-//   (C) Copyright 2002-2005,2010 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id:
+//   (C) Copyright 2002-2005,2010,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -27,9 +25,8 @@
 #include <globals.h>
 #include <btsrc16.h>
 
-
-BtSrc16::BtSrc16(RDMatrix *matrix,QObject *parent,const char *name)
-  : Switcher(matrix,parent,name)
+BtSrc16::BtSrc16(RDMatrix *matrix,QObject *parent)
+  : Switcher(matrix,parent)
 {
   //
   // Initialize Data Structures
@@ -65,11 +62,9 @@ BtSrc16::BtSrc16(RDMatrix *matrix,QObject *parent,const char *name)
   // Interval OneShots
   //
   bt_gpi_oneshot=new RDOneShot(this);
-  connect(bt_gpi_oneshot,SIGNAL(timeout(void *)),
-	  this,SLOT(gpiOneshotData(void*)));
+  connect(bt_gpi_oneshot,SIGNAL(timeout(int)),this,SLOT(gpiOneshotData(int)));
   bt_gpo_oneshot=new RDOneShot(this);
-  connect(bt_gpo_oneshot,SIGNAL(timeout(void *)),
-	  this,SLOT(gpoOneshotData(void*)));
+  connect(bt_gpo_oneshot,SIGNAL(timeout(int)),this,SLOT(gpoOneshotData(int)));
 
   //
   // The Poll Timer
@@ -120,7 +115,7 @@ bool BtSrc16::secondaryTtyActive()
 
 void BtSrc16::processCommand(RDMacro *cmd)
 {
-  char str[9];
+  char str[20];
 
   switch(cmd->command()) {
       case RDMacro::GO:
@@ -189,7 +184,7 @@ void BtSrc16::processCommand(RDMacro *cmd)
 		  bt_gpi_state[cmd->arg(2).toInt()-1]=true;
 		}
 		bt_gpi_mask[cmd->arg(2).toInt()-1]=true;
-		bt_gpi_oneshot->start((void *)(cmd->arg(2).toInt()-1),500);
+		bt_gpi_oneshot->start(cmd->arg(2).toInt()-1,500);
 	      }
 	      if(cmd->arg(1).toString().lower()=="o") {
 		sprintf(str,"*%dOR%02dP%02d\r\n",
@@ -197,7 +192,7 @@ void BtSrc16::processCommand(RDMacro *cmd)
 			cmd->arg(4).toInt()/100+1);
 		bt_device->writeBlock(str,11);
 		emit gpoChanged(bt_matrix,cmd->arg(2).toInt()-1,true);
-		bt_gpo_oneshot->start((void *)(cmd->arg(2).toInt()-1),500);
+		bt_gpo_oneshot->start(cmd->arg(2).toInt()-1,500);
 	      }
 	    }
 	  }
@@ -333,14 +328,14 @@ void BtSrc16::processStatus()
 }
 
 
-void BtSrc16::gpiOneshotData(void *data)
+void BtSrc16::gpiOneshotData(int value)
 {
-  bt_gpi_mask[(long)data]=false;
+  bt_gpi_mask[value]=false;
   bt_device->writeBlock("*0SPA",5);
 }
 
 
-void BtSrc16::gpoOneshotData(void *data)
+void BtSrc16::gpoOneshotData(int value)
 {
-  emit gpoChanged(bt_matrix,(long)data,false);
+  emit gpoChanged(bt_matrix,value,false);
 }
