@@ -2,7 +2,7 @@
 //
 // Load Switcher drivers for ripcd(8)
 //
-//   (C) Copyright 2002-2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2017 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,47 +20,51 @@
 
 #include <stdlib.h>
 
-#include <ripcd.h>
-#include <switcher.h>
-#include <globals.h>
-#include <acu1p.h>
-#include <am16.h>
-#include <bt10x1.h>
-#include <bt16x1.h>
-#include <bt16x2.h>
-#include <bt8x2.h>
-#include <btacs82.h>
-#include <btadms4422.h>
-#include <btgpi16.h>
-#include <btsentinel4web.h>
-#include <btsrc16.h>
-#include <btsrc8iii.h>
-#include <btss124.h>
-#include <btss164.h>
-#include <btss41mlr.h>
-#include <btss42.h>
-#include <btss44.h>
-#include <btss82.h>
-#include <harlond.h>
-#include <kernelgpio.h>
-#include <livewire_lwrpaudio.h>
-#include <livewire_lwrpgpio.h>
-#include <livewire_mcastgpio.h>
-#include <local_audio.h>
-#include <local_gpio.h>
-#include <modbus.h>
-#include <modemlines.h>
-#include <quartz1.h>
-#include <rossnkscp.h>
-#include <sas16000.h>
-#include <sas32000.h>
-#include <sas64000.h>
-#include <sas64000gpi.h>
-#include <sasusi.h>
-#include <starguide3.h>
-#include <swauthority.h>
-#include <unity4000.h>
-#include <vguest.h>
+#include "ripcd.h"
+#include "switcher.h"
+#include "globals.h"
+#include "acu1p.h"
+#include "am16.h"
+#include "bt10x1.h"
+#include "bt16x1.h"
+#include "bt16x2.h"
+#include "bt8x2.h"
+#include "btacs82.h"
+#include "btadms4422.h"
+#include "btgpi16.h"
+#include "btsentinel4web.h"
+#include "btsrc16.h"
+#include "btsrc8iii.h"
+#include "btss124.h"
+#include "btss164.h"
+#include "btss21.h"
+#include "btss41mlr.h"
+#include "btss42.h"
+#include "btss44.h"
+#include "btss82.h"
+#include "btu41mlrweb.h"
+#include "harlond.h"
+#include "kernelgpio.h"
+#include "livewire_lwrpaudio.h"
+#include "livewire_lwrpgpio.h"
+#include "livewire_mcastgpio.h"
+#include "local_audio.h"
+#include "local_gpio.h"
+#include "modbus.h"
+#include "modemlines.h"
+#include "quartz1.h"
+#include "rossnkscp.h"
+#include "sas16000.h"
+#include "sas32000.h"
+#include "sas64000.h"
+#include "sas64000gpi.h"
+#include "sasusi.h"
+#include "starguide3.h"
+#include "swauthority.h"
+#include "unity4000.h"
+#include "vguest.h"
+#include "wheatnet_lio.h"
+#include "wheatnet_slio.h"
 
 bool MainObject::LoadSwitchDriver(int matrix_num)
 {
@@ -123,6 +127,10 @@ bool MainObject::LoadSwitchDriver(int matrix_num)
     ripcd_switcher[matrix_num]=new BtSs164(matrix,this);
     break;
 
+  case RDMatrix::BtSs21:
+    ripcd_switcher[matrix_num]=new BtSs21(matrix,this);
+    break;
+
   case RDMatrix::BtSs41Mlr:
     ripcd_switcher[matrix_num]=new BtSs41Mlr(matrix,this);
     break;
@@ -139,6 +147,10 @@ bool MainObject::LoadSwitchDriver(int matrix_num)
     ripcd_switcher[matrix_num]=new BtSs82(matrix,this);
     break;
 
+  case RDMatrix::BtU41MlrWeb:
+    ripcd_switcher[matrix_num]=new BtU41MlrWeb(matrix,this);
+    break;
+
   case RDMatrix::Harlond:
     ripcd_switcher[matrix_num]=new Harlond(matrix,this);
     break;
@@ -219,6 +231,14 @@ bool MainObject::LoadSwitchDriver(int matrix_num)
     ripcd_switcher[matrix_num]=new Unity4000(matrix,this);
     break;
 
+  case RDMatrix::WheatnetLio:
+    ripcd_switcher[matrix_num]=new WheatnetLio(matrix,this);
+    break;
+
+  case RDMatrix::WheatnetSlio:
+    ripcd_switcher[matrix_num]=new WheatnetSlio(matrix,this);
+    break;
+
   default:
     ripcd_switcher[matrix_num]=NULL;
     delete matrix;
