@@ -23,6 +23,7 @@
 #include <stdlib.h>
 
 #include <qapplication.h>
+#include <qdir.h>
 #include <qfile.h>
 
 #include <rd.h>
@@ -37,10 +38,18 @@
 
 #include "rdexport.h"
 
-MainObject::MainObject(QObject *parent,const char *name)
-  :QObject(parent,name)
+MainObject::MainObject(QObject *parent)
+  :QObject(parent)
 {
   export_metadata_pattern="%n_%j";
+  export_escape_string="_";
+  export_continue_after_error=false;
+  export_allow_clobber=false;
+  export_samplerate=0;
+  export_bitrate=0;
+  export_channels=0;
+  export_quality=3;
+  export_xml=false;
 
   //
   // Read Command Options
@@ -52,6 +61,19 @@ MainObject::MainObject(QObject *parent,const char *name)
     exit(256);
   }
   for(int i=0;i<(int)cmd->keys()-1;i++) {
+    if(cmd->key(i)=="--allow-clobber") {
+      export_allow_clobber=true;
+      cmd->setProcessed(i,true);
+    }
+    if(cmd->key(i)=="--bitrate") {
+      bool ok=false;
+      export_bitrate=cmd->value(i).toUInt(&ok);
+      if(!ok) {
+	fprintf(stderr,"rdexport: invalid bitrate\n");
+	exit(256);
+      }
+      cmd->setProcessed(i,true);
+    }
     if(cmd->key(i)=="--carts") {
       bool ok=false;
       bool valid=false;
@@ -73,6 +95,61 @@ MainObject::MainObject(QObject *parent,const char *name)
       }
       cmd->setProcessed(i,true);
     }
+    if(cmd->key(i)=="--channels") {
+      bool ok=false;
+      export_channels=cmd->value(i).toUInt(&ok);
+      if((export_channels<1)||(export_channels>2)||(!ok)) {
+	fprintf(stderr,"rdexport: invalid --channels argument\n");
+	exit(256);
+      }
+      cmd->setProcessed(i,true);
+    }
+    if(cmd->key(i)=="--continue-after-error") {
+      export_continue_after_error=true;
+      cmd->setProcessed(i,true);
+    }
+    if(cmd->key(i)=="--escape-string") {
+      if(cmd->value(i)!=SanitizePath(cmd->value(i))) {
+	fprintf(stderr,"rdxport: illegal character(s) in escape string\n");
+	exit(256);
+      }
+      export_escape_string=cmd->value(i);
+      cmd->setProcessed(i,true);
+    }
+    if(cmd->key(i)=="--format") {
+      export_format=cmd->value(i);
+      bool ok=false;
+      if(export_format.lower()=="flac") {
+	export_set_format=RDSettings::Flac;
+	ok=true;
+      }
+      if(export_format.lower()=="mp2") {
+	export_set_format=RDSettings::MpegL2;
+	ok=true;
+      }
+      if(export_format.lower()=="mp3") {
+	export_set_format=RDSettings::MpegL3;
+	ok=true;
+      }
+      if(export_format.lower()=="pcm16") {
+	export_set_format=RDSettings::Pcm16;
+	ok=true;
+      }
+      if(export_format.lower()=="pcm24") {
+	export_set_format=RDSettings::Pcm24;
+	ok=true;
+      }
+      if(export_format.lower()=="vorbis") {
+	export_set_format=RDSettings::OggVorbis;
+	ok=true;
+      }
+      if(!ok) {
+	fprintf(stderr,"rdexport: unknown format \"%s\"\n",
+		(const char *)export_format);
+	exit(256);
+      }
+      cmd->setProcessed(i,true);
+    }
     if(cmd->key(i)=="--group") {
       export_groups.push_back(cmd->value(i));
       cmd->setProcessed(i,true);
@@ -81,22 +158,54 @@ MainObject::MainObject(QObject *parent,const char *name)
       export_metadata_pattern=cmd->value(i);
       cmd->setProcessed(i,true);
     }
+    if(cmd->key(i)=="--quality") {
+      bool ok=false;
+      export_quality=cmd->value(i).toInt(&ok);
+      if((export_quality<-1)||(export_quality>10)||(!ok)) {
+	fprintf(stderr,"rdexport: invalid --quality value\n");
+	exit(256);
+      }
+      cmd->setProcessed(i,true);
+    }
+    if(cmd->key(i)=="--samplerate") {
+      bool ok=false;
+      export_samplerate=cmd->value(i).toUInt(&ok);
+      if(!ok) {
+	fprintf(stderr,"rdexport: invalid samplerate\n");
+	exit(256);
+      }
+      cmd->setProcessed(i,true);
+    }
+    if(cmd->key(i)=="--title") {
+      export_titles.push_back(cmd->value(i));
+      cmd->setProcessed(i,true);
+    }
     if(cmd->key(i)=="--verbose") {
       export_verbose=true;
       cmd->setProcessed(i,true);
     }
+    if(cmd->key(i)=="--xml") {
+      export_xml=true;
+      cmd->setProcessed(i,true);
+    }
     if(!cmd->processed(i)) {
       fprintf(stderr,"rdexport: unrecognized option\n");
-      exit(256);
+      qApp->exit(256);
     }
   }
   export_output_to=cmd->key(cmd->keys()-1);
+  QDir dir;
+  if(!dir.exists(export_output_to)) {
+    fprintf(stderr,"rdexport: no such output directory\n");
+    exit(256);
+  }
 
   //
   // Read Configuration
   //
   export_config=new RDConfig();
   export_config->load();
+  export_config->setModuleName("rdexport");
 
   //
   // Open Database
@@ -138,19 +247,19 @@ MainObject::MainObject(QObject *parent,const char *name)
     exit(256);
   }
 
-  //
-  // RIPC Connection
-  //
-  export_ripc=new RDRipc(export_config->stationName());
-  connect(export_ripc,SIGNAL(userChanged()),this,SLOT(userData()));
-  export_ripc->
-    connectHost("localhost",RIPCD_TCP_PORT,export_config->password());
-
   //
   // Station Configuration
   //
   export_station=new RDStation(export_config->stationName());
 
+  //
+  // RIPC Connection
+  //
+  export_ripc=new RDRipc(export_station,export_config,this);
+  connect(export_ripc,SIGNAL(userChanged()),this,SLOT(userData()));
+  export_ripc->
+    connectHost("localhost",RIPCD_TCP_PORT,export_config->password());
+
   //
   // User
   //
@@ -178,6 +287,14 @@ void MainObject::userData()
     exit(256);
   }
 
+  //
+  // Process Titles
+  //
+  for(unsigned i=0;i<export_titles.size();i++) {
+    Verbose("Processing title \""+export_titles[i]+"\"...");
+    ExportTitle(export_titles[i]);
+  }
+
   //
   // Process Groups
   //
@@ -202,6 +319,23 @@ void MainObject::userData()
 }
 
 
+void MainObject::ExportTitle(const QString &title)
+{
+  QString sql;
+  RDSqlQuery *q;
+
+  sql=QString("select NUMBER from CART where ")+
+    "(TITLE=\""+RDEscapeString(title)+"\")&&"+
+    QString().sprintf("(TYPE=%u) ",RDCart::Audio)+
+    "order by NUMBER";
+  q=new RDSqlQuery(sql);
+  while(q->next()) {
+    ExportCart(q->value(0).toUInt());
+  }
+  delete q;
+}
+
+
 void MainObject::ExportGroup(const QString &groupname)
 {
   QString sql;
@@ -256,30 +390,65 @@ void MainObject::ExportCut(RDCart *cart,RDCut *cut)
      RDAudioInfo::ErrorOk) {
     fprintf(stderr,"rdexport: error getting cut info [%s]\n",
 	    (const char *)RDAudioInfo::errorText(info_err));
-    exit(256);
+    if(export_continue_after_error) {
+      return;
+    }
+    else {
+      exit(256);
+    }
   }
   RDSettings settings;
-  switch(info->format()) {
-  case RDWaveFile::Pcm16:
-    settings.setFormat(RDSettings::Pcm16);
-    break;
+  if(export_format.isEmpty()) {
+    switch(info->format()) {
+    case RDWaveFile::Pcm16:
+      settings.setFormat(RDSettings::Pcm16);
+      break;
 
-  case RDWaveFile::Pcm24:
-    settings.setFormat(RDSettings::Pcm24);
-    break;
+    case RDWaveFile::Pcm24:
+      settings.setFormat(RDSettings::Pcm24);
+      break;
 
-  case RDWaveFile::MpegL2:
-    settings.setFormat(RDSettings::MpegL2);
-    break;
+    case RDWaveFile::MpegL2:
+      settings.setFormat(RDSettings::MpegL2);
+      break;
 
-  default:
-    fprintf(stderr,"rdexport: unsupported source audio format\n");
-    exit(256);
+    default:
+      fprintf(stderr,"rdexport: unsupported source audio format\n");
+      if(export_continue_after_error) {
+	return;
+      }
+      else {
+	exit(256);
+      }
+    }
   }
-  settings.setChannels(info->channels());
-  settings.setSampleRate(info->sampleRate());
-  settings.setBitRate(info->bitRate());
-
+  else {
+    settings.setFormat(export_set_format);
+  }
+  if(export_channels==0) {
+    settings.setChannels(info->channels());
+  }
+  else {
+    settings.setChannels(export_channels);
+  }
+  if(export_samplerate==0) {
+    settings.setSampleRate(info->sampleRate());
+  }
+  else {
+    settings.setSampleRate(export_samplerate);
+  }
+  if(export_bitrate==0) {
+    if(info->bitRate()==0) {
+      settings.setBitRate(256000);
+    }
+    else {
+      settings.setBitRate(info->bitRate());
+    }
+  }
+  else {
+    settings.setBitRate(export_bitrate);
+  }
+  settings.setQuality(export_quality);
   Verbose(QString("exporting cart/cut ")+
 	  QString().sprintf("%06u/%03d",RDCut::cartNumber(cut->cutName()),
 		    RDCut::cutNumber(cut->cutName()))+" ["+cart->title()+"]");
@@ -291,10 +460,31 @@ void MainObject::ExportCut(RDCart *cart,RDCut *cut)
   conv->setEnableMetadata(true);
 
   if((export_err=conv->runExport(export_user->name(),export_user->password(),
-				 &conv_err))!=RDAudioExport::ErrorOk) {
-    fprintf(stderr,"rdexport: exporter error [%s]\n",
+				 &conv_err))==RDAudioExport::ErrorOk) {
+    QStringList f0=f0.split("/",conv->destinationFile());
+    printf("%s\n",(const char *)f0[f0.size()-1]);
+    if(export_xml) {
+      FILE *f=NULL;
+      f0=f0.split(".",conv->destinationFile(),true);
+      QString filename;
+      for(unsigned i=0;i<f0.size()-1;i++) {
+	filename+=f0[i]+".";
+      }
+      filename+="xml";
+      if((f=fopen(filename,"w"))!=NULL) {
+	fprintf(f,"%s\n",
+		(const char *)cart->xml(true,true,&settings,cut->cutNumber()));
+	fclose(f);
+      }
+    }
+  }
+  else {
+    fprintf(stderr,"rdexport: exporter error for output file \"%s\" [%s]\n",
+	    (const char *)conv->destinationFile(),
 	    (const char *)RDAudioExport::errorText(export_err,conv_err));
-    exit(256);
+    if(!export_continue_after_error) {
+      exit(256);
+    }
   }
 
   delete conv;
@@ -326,16 +516,40 @@ QString MainObject::ResolveOutputName(RDCart *cart,RDCut *cut,
   name.replace("%u",cart->userDefined());
   name.replace("%y",QString().sprintf("%d",cart->year()));
 
-  QString ret=name;
-  int count=1;
-  while(QFile::exists(export_output_to+"/"+ret+"."+exten)) {
-    ret=name+QString().sprintf("[%d]",count++);
+  QString ret=SanitizePath(name);
+  if(!export_allow_clobber) {
+    int count=1;
+    while(QFile::exists(export_output_to+"/"+ret+"."+exten)) {
+      ret=name+QString().sprintf("[%d]",count++);
+    }
   }
 
   return export_output_to+"/"+ret+"."+exten;
 }
 
 
+QString MainObject::SanitizePath(const QString &pathname) const
+{
+  //
+  // Remove illegal characters from the filepath.
+  // (from https://msdn.microsoft.com/en-us/library/windows/desktop/aa365247%28v=vs.85%29.aspx#naming_conventions
+  //
+  QString ret=pathname;
+
+  ret.replace("/",export_escape_string);
+  ret.replace(":",export_escape_string);
+  ret.replace("<",export_escape_string);
+  ret.replace(">",export_escape_string);
+  ret.replace("\"",export_escape_string);
+  ret.replace("\\",export_escape_string);
+  ret.replace("|",export_escape_string);
+  ret.replace("?",export_escape_string);
+  ret.replace("*",export_escape_string);
+
+  return ret;
+}
+
+
 void MainObject::Verbose(const QString &msg)
 {
   if(export_verbose) {
@@ -347,6 +561,6 @@ void MainObject::Verbose(const QString &msg)
 int main(int argc,char *argv[])
 {
   QApplication a(argc,argv,false);
-  new MainObject(NULL);
+  new MainObject();
   return a.exec();
 }
