@@ -145,7 +145,7 @@ void Xport::Export()
     XmlExit("unable to create temporary directory ["+err_msg+"]",500);
   }
   QString tmpfile=tempdir->path()+"/exported_audio";
-  RDAudioConvert *conv=new RDAudioConvert(xport_config->stationName());
+  RDAudioConvert *conv=new RDAudioConvert(xport_config);
   conv->setSourceFile(RDCut::pathName(cartnum,cutnum));
   conv->setDestinationFile(tmpfile);
   conv->setDestinationSettings(settings);
